---
name: Bug report
about: Create a report to help us improve
title: 'BUG: '
labels: 'bug'
assignees: ''

---

Describe the bug
================
A clear and concise description of what the bug is.

To Reproduce
------------
Steps to reproduce the behavior:
1. Go to '...'
2. Click on '....'
3. Scroll down to '....'
4. See error

Expected behavior
-----------------
A clear and concise description of what you expected to happen.

Screenshots
-----------
If applicable, add screenshots to help explain your problem.

Computer
--------
Please provide the following information:
* OS: (e.g., iOS)
* Python version: (e.g., 3.6)
* Compiler with version: (e.g., gfortran 47)
* Apexpy version/branch: (e.g., 1.1.0/main)

Additional context
------------------
Add any other context about the problem here.
